==> bellsoft-jdk21.0.9+11-src-full.tar.gz: jdk-21.0.9-full/openjfx/modules/javafx.base/src/test/java/test/javafx/util/converter/BigDecimalStringConverterTest.java <==
/*
 * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.javafx.util.converter;

import java.math.BigDecimal;
import java.math.BigInteger;
import static org.junit.Assert.assertEquals;
import javafx.util.converter.BigDecimalStringConverter;

import org.junit.Before;
import org.junit.Test;

/**
 */
public class BigDecimalStringConverterTest {
    private BigDecimalStringConverter converter;

    private final BigDecimal bigDecimal = new BigDecimal(BigInteger.TEN);

    @Before public void setup() {
        converter = new BigDecimalStringConverter();
    }

    @Test public void fromString_testValidStringInput() {
        assertEquals(bigDecimal, converter.fromString("10"));
    }

    @Test public void fromString_testValidStringInputWithWhiteSpace() {
        assertEquals(bigDecimal, converter.fromString("      10      "));
    }

    @Test public void toString_testStringInput() {
        assertEquals("10", converter.toString(bigDecimal));
    }
}

==> bellsoft-jdk25.0.1+11-src-full.tar.gz: jdk-25.0.1-full/openjfx/modules/javafx.base/src/test/java/test/javafx/util/converter/BigDecimalStringConverterTest.java <==
/*
 * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.javafx.util.converter;

import java.math.BigDecimal;
import java.math.BigInteger;
import static org.junit.jupiter.api.Assertions.assertEquals;
import javafx.util.converter.BigDecimalStringConverter;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 */
public class BigDecimalStringConverterTest {
    private BigDecimalStringConverter converter;

    private final BigDecimal bigDecimal = new BigDecimal(BigInteger.TEN);

    @BeforeEach public void setup() {
        converter = new BigDecimalStringConverter();
    }

    @Test public void fromString_testValidStringInput() {
        assertEquals(bigDecimal, converter.fromString("10"));
    }

    @Test public void fromString_testValidStringInputWithWhiteSpace() {
        assertEquals(bigDecimal, converter.fromString("      10      "));
    }

    @Test public void toString_testStringInput() {
        assertEquals("10", converter.toString(bigDecimal));
    }
}
